"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createGraphQL = void 0;
var _apiHeadlessCms = require("@webiny/api-headless-cms");
var _handlerAws = require("@webiny/handler-aws");
var _types = require("./types");
var _handlerGraphql = require("@webiny/handler-graphql");
const createGraphQL = () => {
  return new _handlerAws.ContextPlugin(async context => {
    if (!(await (0, _apiHeadlessCms.isHeadlessCmsReady)(context))) {
      return;
    }
    const plugin = new _apiHeadlessCms.CmsGraphQLSchemaPlugin({
      typeDefs: /* GraphQL */`
                type EmptyTrashBinResponseData {
                    id: String
                }

                type EmptyTrashBinResponse {
                    data: EmptyTrashBinResponseData
                    error: CmsError
                }

                extend type Mutation {
                    emptyTrashBin(modelId: String!): EmptyTrashBinResponse
                }
            `,
      resolvers: {
        Mutation: {
          emptyTrashBin: async (_, args) => {
            const response = await context.tasks.trigger({
              definition: _types.EntriesTask.EmptyTrashBinByModel,
              input: {
                modelId: args.modelId
              }
            });
            return new _handlerGraphql.Response({
              id: response.id
            });
          }
        }
      }
    });
    plugin.name = "headless-cms.graphql.schema.trashBin.types";
    context.plugins.register([plugin]);
  });
};
exports.createGraphQL = createGraphQL;

//# sourceMappingURL=graphql.js.map