"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createEmptyTrashBinsTask = void 0;
var _tasks = require("@webiny/tasks");
var _common = require("../common");
var _types = require("../../types");
const createEmptyTrashBinsTask = () => {
  return (0, _tasks.createTaskDefinition)({
    id: _types.EntriesTask.EmptyTrashBins,
    title: "Headless CMS - Empty all trash bins",
    description: "Delete all entries found in the trash bin, for each model found in the system.",
    maxIterations: 1,
    run: async params => {
      const {
        response,
        isAborted
      } = params;
      try {
        if (isAborted()) {
          return response.aborted();
        }
        const {
          EmptyTrashBins
        } = await import( /* webpackChunkName: "EmptyTrashBins" */"./useCases/EmptyTrashBins");
        const emptyTrashBins = new EmptyTrashBins();
        return await emptyTrashBins.execute(params);
      } catch (ex) {
        return response.error(ex.message ?? "Error while executing EmptyTrashBins task");
      }
    },
    onDone: async ({
      context,
      task
    }) => {
      /**
       * We want to clean all child tasks and logs, which have no errors.
       */
      const childTasksCleanup = new _common.ChildTasksCleanup();
      try {
        await childTasksCleanup.execute({
          context,
          task
        });
      } catch (ex) {
        console.error("Error while cleaning `EmptyTrashBins` child tasks.", ex);
      }
    }
  });
};
exports.createEmptyTrashBinsTask = createEmptyTrashBinsTask;

//# sourceMappingURL=emptyTrashBinsTask.js.map